Scmepy
======

#### Este é um pacote que faz conversões de várias unidades de medidas.
#### dentre elas:
#### 1. celcius em fahrenheit;
#### 2. fahrenheit em celcius;
#### 3. kelvin em celcius;
#### 4. celcius em kelvin;
#### 5. quilometros em metros por segundo;
#### 6. metros por segundo em quilometros;
#### 7. milhas em quilometros:
#### 8. quilometros em  milhas;
#### 9. graus em  radianos:
#### 10. radianos em graus;
#### 11. polegadas em centimetros;
#### 12. centimetros em polegadas;
#### 13. metros cubicos em litros;
#### 14. litros em metros cubicos;
#### 15. quilograms em libras;
#### 16. libras em quilogramas;
#### 17. jardas em metros;
#### 18. metros em jardas;
#### 19. metros quadrados em acres;
#### 20. acres em metros quadrados;
#### 21. metros quadrados em hectares;
#### 22. hectares em metros quadrados;